# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .collection_view_state_output_views_value import CollectionViewStateOutputViewsValue


class CollectionViewStateOutput(UncheckedBaseModel):
    """
    Complete view state for a collection
    """

    views: typing.Optional[typing.Dict[str, CollectionViewStateOutputViewsValue]] = None
    view_ids: typing.Optional[typing.List[str]] = None
    active_view_id: typing.Optional[str] = None
    active_table_id: typing.Optional[str] = None
    display_settings: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None
    last_synced_at: typing.Optional[dt.datetime] = None
    created_at: typing.Optional[dt.datetime] = None
    updated_at: typing.Optional[dt.datetime] = None
    organization_id: str
    collection_id: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from .actor import Actor
from .legacy_identity import LegacyIdentity

DocumentCreatedBy = typing.Union[LegacyIdentity, Actor]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .create_view_request_settings import CreateViewRequestSettings
from .create_view_request_type import CreateViewRequestType
from .update_view_request_settings import UpdateViewRequestSettings
from .update_view_request_type import UpdateViewRequestType

__all__ = ["CreateViewRequestSettings", "CreateViewRequestType", "UpdateViewRequestSettings", "UpdateViewRequestType"]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .billing import Billing


class Organization(UncheckedBaseModel):
    """
    We ignore extra properties, other services might be responsible for adding
    to the organization document, we do not care about these extra fields.

    TODO<mark>: We still need the extra bit for now since we still have some
    microservices, like workflow. However once we are a true big boi, we can
    use this model for the organization and not worry about other services
    adding to it.
    """

    billing: typing.Optional[Billing] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.request_options import RequestOptions
from ..core.serialization import convert_and_respect_annotation_metadata
from ..core.unchecked_base_model import construct_type
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.http_validation_error import HttpValidationError
from ..types.schema_response import SchemaResponse
from ..types.src_app_http_routes_collection_create_table_response import SrcAppHttpRoutesCollectionCreateTableResponse
from ..types.src_app_http_routes_collection_delete_table_response import SrcAppHttpRoutesCollectionDeleteTableResponse
from ..types.src_app_http_routes_collection_get_table_response import SrcAppHttpRoutesCollectionGetTableResponse
from ..types.src_app_http_routes_collection_get_tables_response import SrcAppHttpRoutesCollectionGetTablesResponse
from ..types.src_app_http_routes_collection_sync_table_response import SrcAppHttpRoutesCollectionSyncTableResponse
from ..types.src_app_http_routes_collection_update_table_response import SrcAppHttpRoutesCollectionUpdateTableResponse
from .types.table_config_input_schema_item import TableConfigInputSchemaItem
from .types.table_data_schema_item import TableDataSchemaItem

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawTablesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list(
        self, collection_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[SrcAppHttpRoutesCollectionGetTablesResponse]:
        """
        Parameters
        ----------
        collection_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[SrcAppHttpRoutesCollectionGetTablesResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SrcAppHttpRoutesCollectionGetTablesResponse,
                    construct_type(
                        type_=SrcAppHttpRoutesCollectionGetTablesResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def create(
        self,
        collection_id: str,
        *,
        table_display_name: typing.Optional[str] = OMIT,
        table_img_url: typing.Optional[str] = OMIT,
        table_description: typing.Optional[str] = OMIT,
        schema: typing.Optional[typing.Sequence[TableConfigInputSchemaItem]] = OMIT,
        icon_emoji: typing.Optional[str] = OMIT,
        icon_asset_url: typing.Optional[str] = OMIT,
        icon_fill: typing.Optional[str] = OMIT,
        singular_name: typing.Optional[str] = OMIT,
        plural_name: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[SrcAppHttpRoutesCollectionCreateTableResponse]:
        """
        Parameters
        ----------
        collection_id : str

        table_display_name : typing.Optional[str]

        table_img_url : typing.Optional[str]

        table_description : typing.Optional[str]

        schema : typing.Optional[typing.Sequence[TableConfigInputSchemaItem]]

        icon_emoji : typing.Optional[str]

        icon_asset_url : typing.Optional[str]

        icon_fill : typing.Optional[str]

        singular_name : typing.Optional[str]

        plural_name : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[SrcAppHttpRoutesCollectionCreateTableResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables",
            method="POST",
            json={
                "table_display_name": table_display_name,
                "table_img_url": table_img_url,
                "table_description": table_description,
                "schema": convert_and_respect_annotation_metadata(
                    object_=schema, annotation=typing.Sequence[TableConfigInputSchemaItem], direction="write"
                ),
                "icon_emoji": icon_emoji,
                "icon_asset_url": icon_asset_url,
                "icon_fill": icon_fill,
                "singular_name": singular_name,
                "plural_name": plural_name,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SrcAppHttpRoutesCollectionCreateTableResponse,
                    construct_type(
                        type_=SrcAppHttpRoutesCollectionCreateTableResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get(
        self, collection_id: str, table_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[SrcAppHttpRoutesCollectionGetTableResponse]:
        """
        Parameters
        ----------
        collection_id : str

        table_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[SrcAppHttpRoutesCollectionGetTableResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SrcAppHttpRoutesCollectionGetTableResponse,
                    construct_type(
                        type_=SrcAppHttpRoutesCollectionGetTableResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def update(
        self,
        collection_id: str,
        table_id: str,
        *,
        table_display_name: typing.Optional[str] = OMIT,
        table_img_url: typing.Optional[str] = OMIT,
        table_description: typing.Optional[str] = OMIT,
        schema: typing.Optional[typing.Sequence[TableDataSchemaItem]] = OMIT,
        icon_emoji: typing.Optional[str] = OMIT,
        icon_asset_url: typing.Optional[str] = OMIT,
        icon_fill: typing.Optional[str] = OMIT,
        singular_name: typing.Optional[str] = OMIT,
        plural_name: typing.Optional[str] = OMIT,
        index_id: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[SrcAppHttpRoutesCollectionUpdateTableResponse]:
        """
        Parameters
        ----------
        collection_id : str

        table_id : str

        table_display_name : typing.Optional[str]

        table_img_url : typing.Optional[str]

        table_description : typing.Optional[str]

        schema : typing.Optional[typing.Sequence[TableDataSchemaItem]]

        icon_emoji : typing.Optional[str]

        icon_asset_url : typing.Optional[str]

        icon_fill : typing.Optional[str]

        singular_name : typing.Optional[str]

        plural_name : typing.Optional[str]

        index_id : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[SrcAppHttpRoutesCollectionUpdateTableResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}",
            method="PUT",
            json={
                "table_display_name": table_display_name,
                "table_img_url": table_img_url,
                "table_description": table_description,
                "schema": convert_and_respect_annotation_metadata(
                    object_=schema, annotation=typing.Sequence[TableDataSchemaItem], direction="write"
                ),
                "icon_emoji": icon_emoji,
                "icon_asset_url": icon_asset_url,
                "icon_fill": icon_fill,
                "singular_name": singular_name,
                "plural_name": plural_name,
                "index_id": index_id,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SrcAppHttpRoutesCollectionUpdateTableResponse,
                    construct_type(
                        type_=SrcAppHttpRoutesCollectionUpdateTableResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def delete(
        self, collection_id: str, table_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[SrcAppHttpRoutesCollectionDeleteTableResponse]:
        """
        Delete a table given a collection_id and table_id.

        Parameters
        ----------
        collection_id : str

        table_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[SrcAppHttpRoutesCollectionDeleteTableResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SrcAppHttpRoutesCollectionDeleteTableResponse,
                    construct_type(
                        type_=SrcAppHttpRoutesCollectionDeleteTableResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_schema(
        self, collection_id: str, table_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[SchemaResponse]:
        """
        Parameters
        ----------
        collection_id : str

        table_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[SchemaResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}/schema",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SchemaResponse,
                    construct_type(
                        type_=SchemaResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def sync(
        self,
        collection_id: str,
        table_id: str,
        *,
        request: typing.Sequence[typing.Dict[str, typing.Optional[typing.Any]]],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[SrcAppHttpRoutesCollectionSyncTableResponse]:
        """
        Sync a table with a list of documents.

        Parameters
        ----------
        collection_id : str

        table_id : str

        request : typing.Sequence[typing.Dict[str, typing.Optional[typing.Any]]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[SrcAppHttpRoutesCollectionSyncTableResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}/sync",
            method="POST",
            json=request,
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SrcAppHttpRoutesCollectionSyncTableResponse,
                    construct_type(
                        type_=SrcAppHttpRoutesCollectionSyncTableResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawTablesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list(
        self, collection_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[SrcAppHttpRoutesCollectionGetTablesResponse]:
        """
        Parameters
        ----------
        collection_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[SrcAppHttpRoutesCollectionGetTablesResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SrcAppHttpRoutesCollectionGetTablesResponse,
                    construct_type(
                        type_=SrcAppHttpRoutesCollectionGetTablesResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def create(
        self,
        collection_id: str,
        *,
        table_display_name: typing.Optional[str] = OMIT,
        table_img_url: typing.Optional[str] = OMIT,
        table_description: typing.Optional[str] = OMIT,
        schema: typing.Optional[typing.Sequence[TableConfigInputSchemaItem]] = OMIT,
        icon_emoji: typing.Optional[str] = OMIT,
        icon_asset_url: typing.Optional[str] = OMIT,
        icon_fill: typing.Optional[str] = OMIT,
        singular_name: typing.Optional[str] = OMIT,
        plural_name: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[SrcAppHttpRoutesCollectionCreateTableResponse]:
        """
        Parameters
        ----------
        collection_id : str

        table_display_name : typing.Optional[str]

        table_img_url : typing.Optional[str]

        table_description : typing.Optional[str]

        schema : typing.Optional[typing.Sequence[TableConfigInputSchemaItem]]

        icon_emoji : typing.Optional[str]

        icon_asset_url : typing.Optional[str]

        icon_fill : typing.Optional[str]

        singular_name : typing.Optional[str]

        plural_name : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[SrcAppHttpRoutesCollectionCreateTableResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables",
            method="POST",
            json={
                "table_display_name": table_display_name,
                "table_img_url": table_img_url,
                "table_description": table_description,
                "schema": convert_and_respect_annotation_metadata(
                    object_=schema, annotation=typing.Sequence[TableConfigInputSchemaItem], direction="write"
                ),
                "icon_emoji": icon_emoji,
                "icon_asset_url": icon_asset_url,
                "icon_fill": icon_fill,
                "singular_name": singular_name,
                "plural_name": plural_name,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SrcAppHttpRoutesCollectionCreateTableResponse,
                    construct_type(
                        type_=SrcAppHttpRoutesCollectionCreateTableResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get(
        self, collection_id: str, table_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[SrcAppHttpRoutesCollectionGetTableResponse]:
        """
        Parameters
        ----------
        collection_id : str

        table_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[SrcAppHttpRoutesCollectionGetTableResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SrcAppHttpRoutesCollectionGetTableResponse,
                    construct_type(
                        type_=SrcAppHttpRoutesCollectionGetTableResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def update(
        self,
        collection_id: str,
        table_id: str,
        *,
        table_display_name: typing.Optional[str] = OMIT,
        table_img_url: typing.Optional[str] = OMIT,
        table_description: typing.Optional[str] = OMIT,
        schema: typing.Optional[typing.Sequence[TableDataSchemaItem]] = OMIT,
        icon_emoji: typing.Optional[str] = OMIT,
        icon_asset_url: typing.Optional[str] = OMIT,
        icon_fill: typing.Optional[str] = OMIT,
        singular_name: typing.Optional[str] = OMIT,
        plural_name: typing.Optional[str] = OMIT,
        index_id: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[SrcAppHttpRoutesCollectionUpdateTableResponse]:
        """
        Parameters
        ----------
        collection_id : str

        table_id : str

        table_display_name : typing.Optional[str]

        table_img_url : typing.Optional[str]

        table_description : typing.Optional[str]

        schema : typing.Optional[typing.Sequence[TableDataSchemaItem]]

        icon_emoji : typing.Optional[str]

        icon_asset_url : typing.Optional[str]

        icon_fill : typing.Optional[str]

        singular_name : typing.Optional[str]

        plural_name : typing.Optional[str]

        index_id : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[SrcAppHttpRoutesCollectionUpdateTableResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}",
            method="PUT",
            json={
                "table_display_name": table_display_name,
                "table_img_url": table_img_url,
                "table_description": table_description,
                "schema": convert_and_respect_annotation_metadata(
                    object_=schema, annotation=typing.Sequence[TableDataSchemaItem], direction="write"
                ),
                "icon_emoji": icon_emoji,
                "icon_asset_url": icon_asset_url,
                "icon_fill": icon_fill,
                "singular_name": singular_name,
                "plural_name": plural_name,
                "index_id": index_id,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SrcAppHttpRoutesCollectionUpdateTableResponse,
                    construct_type(
                        type_=SrcAppHttpRoutesCollectionUpdateTableResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def delete(
        self, collection_id: str, table_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[SrcAppHttpRoutesCollectionDeleteTableResponse]:
        """
        Delete a table given a collection_id and table_id.

        Parameters
        ----------
        collection_id : str

        table_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[SrcAppHttpRoutesCollectionDeleteTableResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SrcAppHttpRoutesCollectionDeleteTableResponse,
                    construct_type(
                        type_=SrcAppHttpRoutesCollectionDeleteTableResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_schema(
        self, collection_id: str, table_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[SchemaResponse]:
        """
        Parameters
        ----------
        collection_id : str

        table_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[SchemaResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}/schema",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SchemaResponse,
                    construct_type(
                        type_=SchemaResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def sync(
        self,
        collection_id: str,
        table_id: str,
        *,
        request: typing.Sequence[typing.Dict[str, typing.Optional[typing.Any]]],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[SrcAppHttpRoutesCollectionSyncTableResponse]:
        """
        Sync a table with a list of documents.

        Parameters
        ----------
        collection_id : str

        table_id : str

        request : typing.Sequence[typing.Dict[str, typing.Optional[typing.Any]]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[SrcAppHttpRoutesCollectionSyncTableResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/tables/{jsonable_encoder(table_id)}/sync",
            method="POST",
            json=request,
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SrcAppHttpRoutesCollectionSyncTableResponse,
                    construct_type(
                        type_=SrcAppHttpRoutesCollectionSyncTableResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.run_log import RunLog
from ...types.run_log_pagination import RunLogPagination

WorkflowLogsListLogsResponse = typing.Union[RunLog, RunLogPagination]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .typescript_automation_config import TypescriptAutomationConfig
from .action_type import ActionType
from .actor import Actor
from .actor_identity import ActorIdentity
from .actor_identity_id import ActorIdentityId
from .actor_identity_type import ActorIdentityType
from .agent_automation_config import AgentAutomationConfig
from .agent_revision import AgentRevision
from .agent_revision_model import AgentRevisionModel
from .agent_revision_response_style import AgentRevisionResponseStyle
from .ai_agent import AiAgent
from .api_key_auth_type import ApiKeyAuthType
from .api_key_identity import ApiKeyIdentity
from .api_key_identity_details import ApiKeyIdentityDetails
from .bare_input import BareInput
from .bare_output import BareOutput
from .baseline import Baseline
from .billing import Billing
from .billing_cycle import BillingCycle
from .billing_cycles import BillingCycles
from .billing_usage import BillingUsage
from .block_config_item_boolean import BlockConfigItemBoolean
from .block_config_item_json import BlockConfigItemJson
from .block_config_item_llm import BlockConfigItemLlm
from .block_config_item_number import BlockConfigItemNumber
from .block_config_item_number_default_value import BlockConfigItemNumberDefaultValue
from .block_config_item_number_maximum_value import BlockConfigItemNumberMaximumValue
from .block_config_item_number_minimum_value import BlockConfigItemNumberMinimumValue
from .block_config_item_number_value import BlockConfigItemNumberValue
from .block_config_item_select import BlockConfigItemSelect
from .block_config_item_text_long import BlockConfigItemTextLong
from .block_config_item_text_long_value import BlockConfigItemTextLongValue
from .block_config_item_text_short import BlockConfigItemTextShort
from .block_input import BlockInput
from .block_input_block_config_item import BlockInputBlockConfigItem
from .block_output import BlockOutput
from .block_output_block_config_item import BlockOutputBlockConfigItem
from .block_run import BlockRun
from .block_run_completed import BlockRunCompleted
from .block_run_completed_data import BlockRunCompletedData
from .block_run_completed_environment import BlockRunCompletedEnvironment
from .block_run_failed import BlockRunFailed
from .block_run_failed_data import BlockRunFailedData
from .block_run_failed_environment import BlockRunFailedEnvironment
from .block_run_started import BlockRunStarted
from .block_run_started_data import BlockRunStartedData
from .block_run_started_environment import BlockRunStartedEnvironment
from .block_run_usage import BlockRunUsage
from .block_state_updated import BlockStateUpdated
from .block_state_updated_data import BlockStateUpdatedData
from .block_state_updated_data_update_type import BlockStateUpdatedDataUpdateType
from .block_state_updated_environment import BlockStateUpdatedEnvironment
from .cancel_response import CancelResponse
from .card_display_field import CardDisplayField
from .channel import Channel
from .check_box_column import CheckBoxColumn
from .check_box_column_automation_config import CheckBoxColumnAutomationConfig
from .collection import Collection
from .collection_config import CollectionConfig
from .collection_destination import CollectionDestination
from .collection_view_state_input import CollectionViewStateInput
from .collection_view_state_input_views_value import CollectionViewStateInputViewsValue
from .collection_view_state_output import CollectionViewStateOutput
from .collection_view_state_output_views_value import CollectionViewStateOutputViewsValue
from .column_type import ColumnType
from .column_type_base import ColumnTypeBase
from .column_type_base_automation_config import ColumnTypeBaseAutomationConfig
from .condition import Condition
from .condition_field import ConditionField
from .condition_operator import ConditionOperator
from .connect_integration_request_auth_type import ConnectIntegrationRequestAuthType
from .copilot import Copilot
from .copilot_config import CopilotConfig
from .copilot_config_code_theme import CopilotConfigCodeTheme
from .copilot_config_fab_value import CopilotConfigFabValue
from .copilot_config_mode import CopilotConfigMode
from .create_integrations_response import CreateIntegrationsResponse
from .create_tag_response import CreateTagResponse
from .cron_trigger_config import CronTriggerConfig
from .cron_trigger_config_action import CronTriggerConfigAction
from .custom import Custom
from .daily_usage import DailyUsage
from .data_type import DataType
from .date_time_column import DateTimeColumn
from .date_time_column_automation_config import DateTimeColumnAutomationConfig
from .default_input import DefaultInput
from .default_output import DefaultOutput
from .delete_trigger_response import DeleteTriggerResponse
from .delete_view_response import DeleteViewResponse
from .dependency import Dependency
from .dimensions import Dimensions
from .document import Document
from .document_created_by import DocumentCreatedBy
from .document_data_value import DocumentDataValue
from .document_last_updated_by import DocumentLastUpdatedBy
from .document_response import DocumentResponse
from .edge_ui import EdgeUi
from .environment import Environment
from .environment_config import EnvironmentConfig
from .environment_deployment_config import EnvironmentDeploymentConfig
from .environment_deployment_config_revision_lookup import EnvironmentDeploymentConfigRevisionLookup
from .environment_deployment_document import EnvironmentDeploymentDocument
from .event_version import EventVersion
from .execute_trigger_response import ExecuteTriggerResponse
from .favor import Favor
from .favorite_item import FavoriteItem
from .file import File
from .files_attribute import FilesAttribute
from .files_response import FilesResponse
from .filter_operator import FilterOperator
from .filter_type import FilterType
from .followup_email_request import FollowupEmailRequest
from .friendly_invoice import FriendlyInvoice
from .friendly_payment_methods import FriendlyPaymentMethods
from .html_2_text import Html2Text
from .http import Http
from .http_validation_error import HttpValidationError
from .identity import Identity
from .identity_details import IdentityDetails
from .identity_types import IdentityTypes
from .integration import Integration
from .integration_auth_type import IntegrationAuthType
from .integration_connection import IntegrationConnection
from .integration_connection_auth_type import IntegrationConnectionAuthType
from .integration_connection_integration_type import IntegrationConnectionIntegrationType
from .integration_with_connections import IntegrationWithConnections
from .integration_with_connections_id import IntegrationWithConnectionsId
from .interval import Interval
from .interval_types import IntervalTypes
from .invoice import Invoice
from .invoice_meta import InvoiceMeta
from .invoice_status import InvoiceStatus
from .json_column import JsonColumn
from .json_column_automation_config import JsonColumnAutomationConfig
from .kanban_view_input import KanbanViewInput
from .kanban_view_output import KanbanViewOutput
from .kanban_view_settings import KanbanViewSettings
from .legacy_identity import LegacyIdentity
from .legacy_identity_details import LegacyIdentityDetails
from .line_item import LineItem
from .list_tags_response import ListTagsResponse
from .list_triggers_response import ListTriggersResponse
from .mapping import Mapping
from .mark_down_with_context import MarkDownWithContext
from .markdown_column import MarkdownColumn
from .markdown_column_automation_config import MarkdownColumnAutomationConfig
from .markdown_splitter_config import MarkdownSplitterConfig
from .mcp_auth_type import McpAuthType
from .message import Message
from .message_chunk import MessageChunk
from .model_provider import ModelProvider
from .multi_page_crawler_settings_input import MultiPageCrawlerSettingsInput
from .multi_page_crawler_settings_input_scraper import MultiPageCrawlerSettingsInputScraper
from .multi_page_crawler_settings_input_text_extractor import MultiPageCrawlerSettingsInputTextExtractor
from .multi_page_crawler_settings_output import MultiPageCrawlerSettingsOutput
from .multi_page_crawler_settings_output_scraper import MultiPageCrawlerSettingsOutputScraper
from .multi_page_crawler_settings_output_text_extractor import MultiPageCrawlerSettingsOutputTextExtractor
from .multi_select_column import MultiSelectColumn
from .multi_select_column_automation_config import MultiSelectColumnAutomationConfig
from .node_ui import NodeUi
from .notification import Notification
from .notification_action import NotificationAction
from .notification_action_type import NotificationActionType
from .notification_severity import NotificationSeverity
from .notification_type import NotificationType
from .notion_filter_by import NotionFilterBy
from .notion_filter_options import NotionFilterOptions
from .number_column import NumberColumn
from .number_column_automation_config import NumberColumnAutomationConfig
from .number_column_default import NumberColumnDefault
from .number_column_max_value import NumberColumnMaxValue
from .number_column_min_value import NumberColumnMinValue
from .o_auth_auth_type import OAuthAuthType
from .organization import Organization
from .paragraph_splitter_config import ParagraphSplitterConfig
from .participant import Participant
from .participant_type import ParticipantType
from .placeholder_input import PlaceholderInput
from .placeholder_input_type import PlaceholderInputType
from .placeholder_output import PlaceholderOutput
from .placeholder_output_type import PlaceholderOutputType
from .plan_types import PlanTypes
from .playwright import Playwright
from .playwright_wait_for_load_state import PlaywrightWaitForLoadState
from .position import Position
from .prompt import Prompt
from .prompt_role import PromptRole
from .query_sort import QuerySort
from .readability import Readability
from .recursive_splitter_config import RecursiveSplitterConfig
from .relation_column import RelationColumn
from .relation_column_automation_config import RelationColumnAutomationConfig
from .req_body import ReqBody
from .request_body import RequestBody
from .response_model_usage import ResponseModelUsage
from .result import Result
from .rule import Rule
from .rules_input import RulesInput
from .rules_output import RulesOutput
from .run_log import RunLog
from .run_log_pagination import RunLogPagination
from .schedule import Schedule
from .schema_response import SchemaResponse
from .scout_user import ScoutUser
from .select_column import SelectColumn
from .select_column_automation_config import SelectColumnAutomationConfig
from .select_option_item import SelectOptionItem
from .sentence_splitter_config import SentenceSplitterConfig
from .service_info import ServiceInfo
from .single_page_crawler_settings_input import SinglePageCrawlerSettingsInput
from .single_page_crawler_settings_input_scraper import SinglePageCrawlerSettingsInputScraper
from .single_page_crawler_settings_input_text_extractor import SinglePageCrawlerSettingsInputTextExtractor
from .single_page_crawler_settings_output import SinglePageCrawlerSettingsOutput
from .single_page_crawler_settings_output_scraper import SinglePageCrawlerSettingsOutputScraper
from .single_page_crawler_settings_output_text_extractor import SinglePageCrawlerSettingsOutputTextExtractor
from .sitemap_crawler_settings_input import SitemapCrawlerSettingsInput
from .sitemap_crawler_settings_input_scraper import SitemapCrawlerSettingsInputScraper
from .sitemap_crawler_settings_input_text_extractor import SitemapCrawlerSettingsInputTextExtractor
from .sitemap_crawler_settings_output import SitemapCrawlerSettingsOutput
from .sitemap_crawler_settings_output_scraper import SitemapCrawlerSettingsOutputScraper
from .sitemap_crawler_settings_output_text_extractor import SitemapCrawlerSettingsOutputTextExtractor
from .slack_event_response import SlackEventResponse
from .slack_trigger_config_input import SlackTriggerConfigInput
from .slack_trigger_config_input_action import SlackTriggerConfigInputAction
from .slack_trigger_config_output import SlackTriggerConfigOutput
from .slack_trigger_config_output_action import SlackTriggerConfigOutputAction
from .slack_url_verification import SlackUrlVerification
from .sort_direction import SortDirection
from .source_archetype import SourceArchetype
from .source_archetype_integration_version import SourceArchetypeIntegrationVersion
from .source_sync import SourceSync
from .source_sync_crawl_settings_input import SourceSyncCrawlSettingsInput
from .source_sync_crawl_settings_output import SourceSyncCrawlSettingsOutput
from .source_sync_google_drive_settings import SourceSyncGoogleDriveSettings
from .source_sync_notion_settings_input import SourceSyncNotionSettingsInput
from .source_sync_notion_settings_output import SourceSyncNotionSettingsOutput
from .source_sync_page_crawl_settings_input import SourceSyncPageCrawlSettingsInput
from .source_sync_page_crawl_settings_output import SourceSyncPageCrawlSettingsOutput
from .source_sync_sitemap_settings_input import SourceSyncSitemapSettingsInput
from .source_sync_sitemap_settings_output import SourceSyncSitemapSettingsOutput
from .source_sync_website_settings import SourceSyncWebsiteSettings
from .source_sync_website_settings_splitter import SourceSyncWebsiteSettingsSplitter
from .src_app_http_routes_billing_billing_hourly_data import SrcAppHttpRoutesBillingBillingHourlyData
from .src_app_http_routes_billing_billing_hourly_response import SrcAppHttpRoutesBillingBillingHourlyResponse
from .src_app_http_routes_billing_change_billing_plan_response import SrcAppHttpRoutesBillingChangeBillingPlanResponse
from .src_app_http_routes_billing_create_portal_session_data import SrcAppHttpRoutesBillingCreatePortalSessionData
from .src_app_http_routes_billing_create_portal_session_response import (
    SrcAppHttpRoutesBillingCreatePortalSessionResponse,
)
from .src_app_http_routes_billing_free_plan_usage_data import SrcAppHttpRoutesBillingFreePlanUsageData
from .src_app_http_routes_billing_free_plan_usage_response import SrcAppHttpRoutesBillingFreePlanUsageResponse
from .src_app_http_routes_billing_get_billing_data import SrcAppHttpRoutesBillingGetBillingData
from .src_app_http_routes_billing_get_billing_response import SrcAppHttpRoutesBillingGetBillingResponse
from .src_app_http_routes_billing_get_info_get_info_response import SrcAppHttpRoutesBillingGetInfoGetInfoResponse
from .src_app_http_routes_billing_get_invoices_data import SrcAppHttpRoutesBillingGetInvoicesData
from .src_app_http_routes_billing_get_invoices_response import SrcAppHttpRoutesBillingGetInvoicesResponse
from .src_app_http_routes_billing_get_notifications_response import SrcAppHttpRoutesBillingGetNotificationsResponse
from .src_app_http_routes_billing_renew_plans_data import SrcAppHttpRoutesBillingRenewPlansData
from .src_app_http_routes_billing_renew_plans_response import SrcAppHttpRoutesBillingRenewPlansResponse
from .src_app_http_routes_collection_create_collection_response import (
    SrcAppHttpRoutesCollectionCreateCollectionResponse,
)
from .src_app_http_routes_collection_create_sync_response import SrcAppHttpRoutesCollectionCreateSyncResponse
from .src_app_http_routes_collection_create_table_response import SrcAppHttpRoutesCollectionCreateTableResponse
from .src_app_http_routes_collection_delete_collection_response import (
    SrcAppHttpRoutesCollectionDeleteCollectionResponse,
)
from .src_app_http_routes_collection_delete_documents_response import SrcAppHttpRoutesCollectionDeleteDocumentsResponse
from .src_app_http_routes_collection_delete_sync_response import SrcAppHttpRoutesCollectionDeleteSyncResponse
from .src_app_http_routes_collection_delete_table_response import SrcAppHttpRoutesCollectionDeleteTableResponse
from .src_app_http_routes_collection_get_collection_response import SrcAppHttpRoutesCollectionGetCollectionResponse
from .src_app_http_routes_collection_get_collections_response import SrcAppHttpRoutesCollectionGetCollectionsResponse
from .src_app_http_routes_collection_get_document_response import SrcAppHttpRoutesCollectionGetDocumentResponse
from .src_app_http_routes_collection_get_documents_response import SrcAppHttpRoutesCollectionGetDocumentsResponse
from .src_app_http_routes_collection_get_sync_response import SrcAppHttpRoutesCollectionGetSyncResponse
from .src_app_http_routes_collection_get_table_response import SrcAppHttpRoutesCollectionGetTableResponse
from .src_app_http_routes_collection_get_tables_response import SrcAppHttpRoutesCollectionGetTablesResponse
from .src_app_http_routes_collection_list_collection_syncs_response_model import (
    SrcAppHttpRoutesCollectionListCollectionSyncsResponseModel,
)
from .src_app_http_routes_collection_list_source_archetypes_response_model import (
    SrcAppHttpRoutesCollectionListSourceArchetypesResponseModel,
)
from .src_app_http_routes_collection_parse_file_response import SrcAppHttpRoutesCollectionParseFileResponse
from .src_app_http_routes_collection_sync_table_response import SrcAppHttpRoutesCollectionSyncTableResponse
from .src_app_http_routes_collection_update_collection_response import (
    SrcAppHttpRoutesCollectionUpdateCollectionResponse,
)
from .src_app_http_routes_collection_update_document_response import SrcAppHttpRoutesCollectionUpdateDocumentResponse
from .src_app_http_routes_collection_update_sync_response import SrcAppHttpRoutesCollectionUpdateSyncResponse
from .src_app_http_routes_collection_update_table_response import SrcAppHttpRoutesCollectionUpdateTableResponse
from .src_app_http_routes_inbox_handle_message_incoming_message import SrcAppHttpRoutesInboxHandleMessageIncomingMessage
from .src_app_http_routes_inbox_handle_message_incoming_message_content import (
    SrcAppHttpRoutesInboxHandleMessageIncomingMessageContent,
)
from .src_app_http_routes_inbox_handle_message_incoming_message_content_type import (
    SrcAppHttpRoutesInboxHandleMessageIncomingMessageContentType,
)
from .src_app_http_routes_inbox_handle_message_interaction_request_participants_item import (
    SrcAppHttpRoutesInboxHandleMessageInteractionRequestParticipantsItem,
)
from .src_app_http_routes_onboarding_followup_emails_data import SrcAppHttpRoutesOnboardingFollowupEmailsData
from .src_app_http_routes_onboarding_followup_emails_response import SrcAppHttpRoutesOnboardingFollowupEmailsResponse
from .src_app_http_routes_onboarding_handle_get_me_response import SrcAppHttpRoutesOnboardingHandleGetMeResponse
from .src_app_http_routes_onboarding_handle_update_me_response import SrcAppHttpRoutesOnboardingHandleUpdateMeResponse
from .src_app_http_routes_root_get_info_response import SrcAppHttpRoutesRootGetInfoResponse
from .src_app_http_routes_trigger_create_trigger_response import SrcAppHttpRoutesTriggerCreateTriggerResponse
from .src_app_http_routes_world_interact_incoming_message import SrcAppHttpRoutesWorldInteractIncomingMessage
from .src_app_http_routes_world_interact_incoming_message_content import (
    SrcAppHttpRoutesWorldInteractIncomingMessageContent,
)
from .src_app_http_routes_world_interact_incoming_message_content_item import (
    SrcAppHttpRoutesWorldInteractIncomingMessageContentItem,
)
from .src_app_http_routes_world_interact_interaction_request import SrcAppHttpRoutesWorldInteractInteractionRequest
from .src_handlers_create_copilot_response import SrcHandlersCreateCopilotResponse
from .src_handlers_create_workflow_response import SrcHandlersCreateWorkflowResponse
from .src_handlers_create_workflow_revision_response import SrcHandlersCreateWorkflowRevisionResponse
from .src_handlers_delete_copilot_response import SrcHandlersDeleteCopilotResponse
from .src_handlers_delete_workflow_response import SrcHandlersDeleteWorkflowResponse
from .src_handlers_delete_workflow_revision_response import SrcHandlersDeleteWorkflowRevisionResponse
from .src_handlers_get_copilot_response import SrcHandlersGetCopilotResponse
from .src_handlers_get_workflow_environments_response import SrcHandlersGetWorkflowEnvironmentsResponse
from .src_handlers_get_workflow_response import SrcHandlersGetWorkflowResponse
from .src_handlers_list_copilots_response import SrcHandlersListCopilotsResponse
from .src_handlers_list_workflow_revisions_response import SrcHandlersListWorkflowRevisionsResponse
from .src_handlers_list_workflows_response import SrcHandlersListWorkflowsResponse
from .src_handlers_promote_workflow_revision_response import SrcHandlersPromoteWorkflowRevisionResponse
from .src_handlers_update_copilot_response import SrcHandlersUpdateCopilotResponse
from .src_handlers_update_workflow_environment_response import SrcHandlersUpdateWorkflowEnvironmentResponse
from .src_handlers_update_workflow_response import SrcHandlersUpdateWorkflowResponse
from .stripe_provider import StripeProvider
from .stripe_provider_meta import StripeProviderMeta
from .subscription import Subscription
from .sync import Sync
from .sync_config_input import SyncConfigInput
from .sync_config_input_source_settings import SyncConfigInputSourceSettings
from .sync_config_output import SyncConfigOutput
from .sync_config_output_source_settings import SyncConfigOutputSourceSettings
from .table import Table
from .table_config_output import TableConfigOutput
from .table_config_output_schema_item import TableConfigOutputSchemaItem
from .table_view_input import TableViewInput
from .table_view_output import TableViewOutput
from .table_view_settings import TableViewSettings
from .table_view_settings_row_height import TableViewSettingsRowHeight
from .tag import Tag
from .text_extractor import TextExtractor
from .text_extractor_config import TextExtractorConfig
from .text_long_column import TextLongColumn
from .text_long_column_automation_config import TextLongColumnAutomationConfig
from .text_short_column import TextShortColumn
from .text_short_column_automation_config import TextShortColumnAutomationConfig
from .tool import Tool
from .tools_data import ToolsData
from .tools_response import ToolsResponse
from .trafilatura_input import TrafilaturaInput
from .trafilatura_input_trafilatura_type import TrafilaturaInputTrafilaturaType
from .trafilatura_output import TrafilaturaOutput
from .trafilatura_output_trafilatura_type import TrafilaturaOutputTrafilaturaType
from .trigger import Trigger
from .trigger_status import TriggerStatus
from .trigger_trigger_config import TriggerTriggerConfig
from .units import Units
from .update_cron_auth_response import UpdateCronAuthResponse
from .update_tag_response import UpdateTagResponse
from .update_trigger_response import UpdateTriggerResponse
from .url_column import UrlColumn
from .url_column_automation_config import UrlColumnAutomationConfig
from .usage import Usage
from .usage_types import UsageTypes
from .user import User
from .user_identity import UserIdentity
from .user_identity_details import UserIdentityDetails
from .validation_error import ValidationError
from .validation_error_loc_item import ValidationErrorLocItem
from .view_filter import ViewFilter
from .view_list_response import ViewListResponse
from .view_list_response_data_item import ViewListResponseDataItem
from .view_query_input import ViewQueryInput
from .view_query_output import ViewQueryOutput
from .view_response import ViewResponse
from .view_response_data import ViewResponseData
from .view_state_response import ViewStateResponse
from .view_visibility import ViewVisibility
from .workflow import Workflow
from .workflow_actor import WorkflowActor
from .workflow_actor_type import WorkflowActorType
from .workflow_automation_config import WorkflowAutomationConfig
from .workflow_config_input import WorkflowConfigInput
from .workflow_config_output import WorkflowConfigOutput
from .workflow_execute import WorkflowExecute
from .workflow_note_input import WorkflowNoteInput
from .workflow_note_output import WorkflowNoteOutput
from .workflow_run import WorkflowRun
from .workflow_run_completed import WorkflowRunCompleted
from .workflow_run_completed_data import WorkflowRunCompletedData
from .workflow_run_completed_environment import WorkflowRunCompletedEnvironment
from .workflow_run_failed import WorkflowRunFailed
from .workflow_run_failed_data import WorkflowRunFailedData
from .workflow_run_failed_environment import WorkflowRunFailedEnvironment
from .workflow_run_response import WorkflowRunResponse
from .workflow_run_started import WorkflowRunStarted
from .workflow_run_started_data import WorkflowRunStartedData
from .workflow_run_started_environment import WorkflowRunStartedEnvironment
from .workflow_run_state_value import WorkflowRunStateValue
from .workflow_run_stop_reason import WorkflowRunStopReason
from .workflow_run_stream_response import WorkflowRunStreamResponse

__all__ = [
    "ActionType",
    "Actor",
    "ActorIdentity",
    "ActorIdentityId",
    "ActorIdentityType",
    "AgentAutomationConfig",
    "AgentRevision",
    "AgentRevisionModel",
    "AgentRevisionResponseStyle",
    "AiAgent",
    "ApiKeyAuthType",
    "ApiKeyIdentity",
    "ApiKeyIdentityDetails",
    "BareInput",
    "BareOutput",
    "Baseline",
    "Billing",
    "BillingCycle",
    "BillingCycles",
    "BillingUsage",
    "BlockConfigItemBoolean",
    "BlockConfigItemJson",
    "BlockConfigItemLlm",
    "BlockConfigItemNumber",
    "BlockConfigItemNumberDefaultValue",
    "BlockConfigItemNumberMaximumValue",
    "BlockConfigItemNumberMinimumValue",
    "BlockConfigItemNumberValue",
    "BlockConfigItemSelect",
    "BlockConfigItemTextLong",
    "BlockConfigItemTextLongValue",
    "BlockConfigItemTextShort",
    "BlockInput",
    "BlockInputBlockConfigItem",
    "BlockOutput",
    "BlockOutputBlockConfigItem",
    "BlockRun",
    "BlockRunCompleted",
    "BlockRunCompletedData",
    "BlockRunCompletedEnvironment",
    "BlockRunFailed",
    "BlockRunFailedData",
    "BlockRunFailedEnvironment",
    "BlockRunStarted",
    "BlockRunStartedData",
    "BlockRunStartedEnvironment",
    "BlockRunUsage",
    "BlockStateUpdated",
    "BlockStateUpdatedData",
    "BlockStateUpdatedDataUpdateType",
    "BlockStateUpdatedEnvironment",
    "CancelResponse",
    "CardDisplayField",
    "Channel",
    "CheckBoxColumn",
    "CheckBoxColumnAutomationConfig",
    "Collection",
    "CollectionConfig",
    "CollectionDestination",
    "CollectionViewStateInput",
    "CollectionViewStateInputViewsValue",
    "CollectionViewStateOutput",
    "CollectionViewStateOutputViewsValue",
    "ColumnType",
    "ColumnTypeBase",
    "ColumnTypeBaseAutomationConfig",
    "Condition",
    "ConditionField",
    "ConditionOperator",
    "ConnectIntegrationRequestAuthType",
    "Copilot",
    "CopilotConfig",
    "CopilotConfigCodeTheme",
    "CopilotConfigFabValue",
    "CopilotConfigMode",
    "CreateIntegrationsResponse",
    "CreateTagResponse",
    "CronTriggerConfig",
    "CronTriggerConfigAction",
    "Custom",
    "DailyUsage",
    "DataType",
    "DateTimeColumn",
    "DateTimeColumnAutomationConfig",
    "DefaultInput",
    "DefaultOutput",
    "DeleteTriggerResponse",
    "DeleteViewResponse",
    "Dependency",
    "Dimensions",
    "Document",
    "DocumentCreatedBy",
    "DocumentDataValue",
    "DocumentLastUpdatedBy",
    "DocumentResponse",
    "EdgeUi",
    "Environment",
    "EnvironmentConfig",
    "EnvironmentDeploymentConfig",
    "EnvironmentDeploymentConfigRevisionLookup",
    "EnvironmentDeploymentDocument",
    "EventVersion",
    "ExecuteTriggerResponse",
    "Favor",
    "FavoriteItem",
    "File",
    "FilesAttribute",
    "FilesResponse",
    "FilterOperator",
    "FilterType",
    "FollowupEmailRequest",
    "FriendlyInvoice",
    "FriendlyPaymentMethods",
    "Html2Text",
    "Http",
    "HttpValidationError",
    "Identity",
    "IdentityDetails",
    "IdentityTypes",
    "Integration",
    "IntegrationAuthType",
    "IntegrationConnection",
    "IntegrationConnectionAuthType",
    "IntegrationConnectionIntegrationType",
    "IntegrationWithConnections",
    "IntegrationWithConnectionsId",
    "Interval",
    "IntervalTypes",
    "Invoice",
    "InvoiceMeta",
    "InvoiceStatus",
    "JsonColumn",
    "JsonColumnAutomationConfig",
    "KanbanViewInput",
    "KanbanViewOutput",
    "KanbanViewSettings",
    "LegacyIdentity",
    "LegacyIdentityDetails",
    "LineItem",
    "ListTagsResponse",
    "ListTriggersResponse",
    "Mapping",
    "MarkDownWithContext",
    "MarkdownColumn",
    "MarkdownColumnAutomationConfig",
    "MarkdownSplitterConfig",
    "McpAuthType",
    "Message",
    "MessageChunk",
    "ModelProvider",
    "MultiPageCrawlerSettingsInput",
    "MultiPageCrawlerSettingsInputScraper",
    "MultiPageCrawlerSettingsInputTextExtractor",
    "MultiPageCrawlerSettingsOutput",
    "MultiPageCrawlerSettingsOutputScraper",
    "MultiPageCrawlerSettingsOutputTextExtractor",
    "MultiSelectColumn",
    "MultiSelectColumnAutomationConfig",
    "NodeUi",
    "Notification",
    "NotificationAction",
    "NotificationActionType",
    "NotificationSeverity",
    "NotificationType",
    "NotionFilterBy",
    "NotionFilterOptions",
    "NumberColumn",
    "NumberColumnAutomationConfig",
    "NumberColumnDefault",
    "NumberColumnMaxValue",
    "NumberColumnMinValue",
    "OAuthAuthType",
    "Organization",
    "ParagraphSplitterConfig",
    "Participant",
    "ParticipantType",
    "PlaceholderInput",
    "PlaceholderInputType",
    "PlaceholderOutput",
    "PlaceholderOutputType",
    "PlanTypes",
    "Playwright",
    "PlaywrightWaitForLoadState",
    "Position",
    "Prompt",
    "PromptRole",
    "QuerySort",
    "Readability",
    "RecursiveSplitterConfig",
    "RelationColumn",
    "RelationColumnAutomationConfig",
    "ReqBody",
    "RequestBody",
    "ResponseModelUsage",
    "Result",
    "Rule",
    "RulesInput",
    "RulesOutput",
    "RunLog",
    "RunLogPagination",
    "Schedule",
    "SchemaResponse",
    "ScoutUser",
    "SelectColumn",
    "SelectColumnAutomationConfig",
    "SelectOptionItem",
    "SentenceSplitterConfig",
    "ServiceInfo",
    "SinglePageCrawlerSettingsInput",
    "SinglePageCrawlerSettingsInputScraper",
    "SinglePageCrawlerSettingsInputTextExtractor",
    "SinglePageCrawlerSettingsOutput",
    "SinglePageCrawlerSettingsOutputScraper",
    "SinglePageCrawlerSettingsOutputTextExtractor",
    "SitemapCrawlerSettingsInput",
    "SitemapCrawlerSettingsInputScraper",
    "SitemapCrawlerSettingsInputTextExtractor",
    "SitemapCrawlerSettingsOutput",
    "SitemapCrawlerSettingsOutputScraper",
    "SitemapCrawlerSettingsOutputTextExtractor",
    "SlackEventResponse",
    "SlackTriggerConfigInput",
    "SlackTriggerConfigInputAction",
    "SlackTriggerConfigOutput",
    "SlackTriggerConfigOutputAction",
    "SlackUrlVerification",
    "SortDirection",
    "SourceArchetype",
    "SourceArchetypeIntegrationVersion",
    "SourceSync",
    "SourceSyncCrawlSettingsInput",
    "SourceSyncCrawlSettingsOutput",
    "SourceSyncGoogleDriveSettings",
    "SourceSyncNotionSettingsInput",
    "SourceSyncNotionSettingsOutput",
    "SourceSyncPageCrawlSettingsInput",
    "SourceSyncPageCrawlSettingsOutput",
    "SourceSyncSitemapSettingsInput",
    "SourceSyncSitemapSettingsOutput",
    "SourceSyncWebsiteSettings",
    "SourceSyncWebsiteSettingsSplitter",
    "SrcAppHttpRoutesBillingBillingHourlyData",
    "SrcAppHttpRoutesBillingBillingHourlyResponse",
    "SrcAppHttpRoutesBillingChangeBillingPlanResponse",
    "SrcAppHttpRoutesBillingCreatePortalSessionData",
    "SrcAppHttpRoutesBillingCreatePortalSessionResponse",
    "SrcAppHttpRoutesBillingFreePlanUsageData",
    "SrcAppHttpRoutesBillingFreePlanUsageResponse",
    "SrcAppHttpRoutesBillingGetBillingData",
    "SrcAppHttpRoutesBillingGetBillingResponse",
    "SrcAppHttpRoutesBillingGetInfoGetInfoResponse",
    "SrcAppHttpRoutesBillingGetInvoicesData",
    "SrcAppHttpRoutesBillingGetInvoicesResponse",
    "SrcAppHttpRoutesBillingGetNotificationsResponse",
    "SrcAppHttpRoutesBillingRenewPlansData",
    "SrcAppHttpRoutesBillingRenewPlansResponse",
    "SrcAppHttpRoutesCollectionCreateCollectionResponse",
    "SrcAppHttpRoutesCollectionCreateSyncResponse",
    "SrcAppHttpRoutesCollectionCreateTableResponse",
    "SrcAppHttpRoutesCollectionDeleteCollectionResponse",
    "SrcAppHttpRoutesCollectionDeleteDocumentsResponse",
    "SrcAppHttpRoutesCollectionDeleteSyncResponse",
    "SrcAppHttpRoutesCollectionDeleteTableResponse",
    "SrcAppHttpRoutesCollectionGetCollectionResponse",
    "SrcAppHttpRoutesCollectionGetCollectionsResponse",
    "SrcAppHttpRoutesCollectionGetDocumentResponse",
    "SrcAppHttpRoutesCollectionGetDocumentsResponse",
    "SrcAppHttpRoutesCollectionGetSyncResponse",
    "SrcAppHttpRoutesCollectionGetTableResponse",
    "SrcAppHttpRoutesCollectionGetTablesResponse",
    "SrcAppHttpRoutesCollectionListCollectionSyncsResponseModel",
    "SrcAppHttpRoutesCollectionListSourceArchetypesResponseModel",
    "SrcAppHttpRoutesCollectionParseFileResponse",
    "SrcAppHttpRoutesCollectionSyncTableResponse",
    "SrcAppHttpRoutesCollectionUpdateCollectionResponse",
    "SrcAppHttpRoutesCollectionUpdateDocumentResponse",
    "SrcAppHttpRoutesCollectionUpdateSyncResponse",
    "SrcAppHttpRoutesCollectionUpdateTableResponse",
    "SrcAppHttpRoutesInboxHandleMessageIncomingMessage",
    "SrcAppHttpRoutesInboxHandleMessageIncomingMessageContent",
    "SrcAppHttpRoutesInboxHandleMessageIncomingMessageContentType",
    "SrcAppHttpRoutesInboxHandleMessageInteractionRequestParticipantsItem",
    "SrcAppHttpRoutesOnboardingFollowupEmailsData",
    "SrcAppHttpRoutesOnboardingFollowupEmailsResponse",
    "SrcAppHttpRoutesOnboardingHandleGetMeResponse",
    "SrcAppHttpRoutesOnboardingHandleUpdateMeResponse",
    "SrcAppHttpRoutesRootGetInfoResponse",
    "SrcAppHttpRoutesTriggerCreateTriggerResponse",
    "SrcAppHttpRoutesWorldInteractIncomingMessage",
    "SrcAppHttpRoutesWorldInteractIncomingMessageContent",
    "SrcAppHttpRoutesWorldInteractIncomingMessageContentItem",
    "SrcAppHttpRoutesWorldInteractInteractionRequest",
    "SrcHandlersCreateCopilotResponse",
    "SrcHandlersCreateWorkflowResponse",
    "SrcHandlersCreateWorkflowRevisionResponse",
    "SrcHandlersDeleteCopilotResponse",
    "SrcHandlersDeleteWorkflowResponse",
    "SrcHandlersDeleteWorkflowRevisionResponse",
    "SrcHandlersGetCopilotResponse",
    "SrcHandlersGetWorkflowEnvironmentsResponse",
    "SrcHandlersGetWorkflowResponse",
    "SrcHandlersListCopilotsResponse",
    "SrcHandlersListWorkflowRevisionsResponse",
    "SrcHandlersListWorkflowsResponse",
    "SrcHandlersPromoteWorkflowRevisionResponse",
    "SrcHandlersUpdateCopilotResponse",
    "SrcHandlersUpdateWorkflowEnvironmentResponse",
    "SrcHandlersUpdateWorkflowResponse",
    "StripeProvider",
    "StripeProviderMeta",
    "Subscription",
    "Sync",
    "SyncConfigInput",
    "SyncConfigInputSourceSettings",
    "SyncConfigOutput",
    "SyncConfigOutputSourceSettings",
    "Table",
    "TableConfigOutput",
    "TableConfigOutputSchemaItem",
    "TableViewInput",
    "TableViewOutput",
    "TableViewSettings",
    "TableViewSettingsRowHeight",
    "Tag",
    "TextExtractor",
    "TextExtractorConfig",
    "TextLongColumn",
    "TextLongColumnAutomationConfig",
    "TextShortColumn",
    "TextShortColumnAutomationConfig",
    "Tool",
    "ToolsData",
    "ToolsResponse",
    "TrafilaturaInput",
    "TrafilaturaInputTrafilaturaType",
    "TrafilaturaOutput",
    "TrafilaturaOutputTrafilaturaType",
    "Trigger",
    "TriggerStatus",
    "TriggerTriggerConfig",
    "TypescriptAutomationConfig",
    "Units",
    "UpdateCronAuthResponse",
    "UpdateTagResponse",
    "UpdateTriggerResponse",
    "UrlColumn",
    "UrlColumnAutomationConfig",
    "Usage",
    "UsageTypes",
    "User",
    "UserIdentity",
    "UserIdentityDetails",
    "ValidationError",
    "ValidationErrorLocItem",
    "ViewFilter",
    "ViewListResponse",
    "ViewListResponseDataItem",
    "ViewQueryInput",
    "ViewQueryOutput",
    "ViewResponse",
    "ViewResponseData",
    "ViewStateResponse",
    "ViewVisibility",
    "Workflow",
    "WorkflowActor",
    "WorkflowActorType",
    "WorkflowAutomationConfig",
    "WorkflowConfigInput",
    "WorkflowConfigOutput",
    "WorkflowExecute",
    "WorkflowNoteInput",
    "WorkflowNoteOutput",
    "WorkflowRun",
    "WorkflowRunCompleted",
    "WorkflowRunCompletedData",
    "WorkflowRunCompletedEnvironment",
    "WorkflowRunFailed",
    "WorkflowRunFailedData",
    "WorkflowRunFailedEnvironment",
    "WorkflowRunResponse",
    "WorkflowRunStarted",
    "WorkflowRunStartedData",
    "WorkflowRunStartedEnvironment",
    "WorkflowRunStateValue",
    "WorkflowRunStopReason",
    "WorkflowRunStreamResponse",
]



# This file was auto-generated by Fern from our API Definition.

import typing

from .check_box_column import CheckBoxColumn
from .date_time_column import DateTimeColumn
from .json_column import JsonColumn
from .markdown_column import MarkdownColumn
from .multi_select_column import MultiSelectColumn
from .number_column import NumberColumn
from .relation_column import RelationColumn
from .select_column import SelectColumn
from .text_long_column import TextLongColumn
from .text_short_column import TextShortColumn
from .url_column import UrlColumn

TableConfigOutputSchemaItem = typing.Union[
    CheckBoxColumn,
    DateTimeColumn,
    JsonColumn,
    MarkdownColumn,
    MultiSelectColumn,
    NumberColumn,
    RelationColumn,
    SelectColumn,
    TextLongColumn,
    TextShortColumn,
    UrlColumn,
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import TriggersCreateRequest, TriggersExecuteSlackResponse, TriggersUpdateRequest

__all__ = ["TriggersCreateRequest", "TriggersExecuteSlackResponse", "TriggersUpdateRequest"]



# This file was auto-generated by Fern from our API Definition.

import typing

IntegrationConnectionIntegrationType = typing.Union[
    typing.Literal[
        "hubspot",
        "gmail",
        "web_search",
        "slack",
        "google_drive",
        "google_calendar",
        "notion",
        "gsuite",
        "salesforce",
        "linear",
        "github",
        "attio",
        "mcp",
        "square",
        "paypal",
        "sentry",
        "statsig",
        "scout_native_tools",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

DocumentDataValue = typing.Union[
    str,
    float,
    int,
    bool,
    typing.Dict[str, typing.Optional[typing.Any]],
    typing.List[typing.Optional[typing.Any]],
    dt.datetime,
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class Custom(UncheckedBaseModel):
    text_extractor_type: typing.Literal["custom"] = "custom"
    selectors: typing.Optional[str] = None
    exclude_selectors: typing.Optional[str] = pydantic.Field(default=None)
    """
    Enter a comma-separated list of classes, IDs, or tags to exclude from the content.
    """

    exclude_common_elements: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Exclude common elements like headers, footers, and navigation menus.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from .api_key_identity_details import ApiKeyIdentityDetails
from .user_identity_details import UserIdentityDetails

LegacyIdentityDetails = typing.Union[UserIdentityDetails, ApiKeyIdentityDetails]



# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.workflow_run_response import WorkflowRunResponse
from .workflows_run_with_config_response_zero import WorkflowsRunWithConfigResponseZero

WorkflowsRunWithConfigResponse = typing.Union[WorkflowsRunWithConfigResponseZero, WorkflowRunResponse]



# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.cron_trigger_config import CronTriggerConfig
from ...types.slack_trigger_config_input import SlackTriggerConfigInput

TriggersCreateRequest = typing.Union[SlackTriggerConfigInput, CronTriggerConfig]



# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.check_box_column import CheckBoxColumn
from ...types.date_time_column import DateTimeColumn
from ...types.json_column import JsonColumn
from ...types.markdown_column import MarkdownColumn
from ...types.multi_select_column import MultiSelectColumn
from ...types.number_column import NumberColumn
from ...types.relation_column import RelationColumn
from ...types.select_column import SelectColumn
from ...types.text_long_column import TextLongColumn
from ...types.text_short_column import TextShortColumn
from ...types.url_column import UrlColumn

TableConfigInputSchemaItem = typing.Union[
    CheckBoxColumn,
    DateTimeColumn,
    JsonColumn,
    MarkdownColumn,
    MultiSelectColumn,
    NumberColumn,
    RelationColumn,
    SelectColumn,
    TextLongColumn,
    TextShortColumn,
    UrlColumn,
]



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.schema_response import SchemaResponse
from ..types.src_app_http_routes_collection_create_table_response import SrcAppHttpRoutesCollectionCreateTableResponse
from ..types.src_app_http_routes_collection_delete_table_response import SrcAppHttpRoutesCollectionDeleteTableResponse
from ..types.src_app_http_routes_collection_get_table_response import SrcAppHttpRoutesCollectionGetTableResponse
from ..types.src_app_http_routes_collection_get_tables_response import SrcAppHttpRoutesCollectionGetTablesResponse
from ..types.src_app_http_routes_collection_sync_table_response import SrcAppHttpRoutesCollectionSyncTableResponse
from ..types.src_app_http_routes_collection_update_table_response import SrcAppHttpRoutesCollectionUpdateTableResponse
from .raw_client import AsyncRawTablesClient, RawTablesClient
from .types.table_config_input_schema_item import TableConfigInputSchemaItem
from .types.table_data_schema_item import TableDataSchemaItem

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class TablesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawTablesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawTablesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawTablesClient
        """
        return self._raw_client

    def list(
        self, collection_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcAppHttpRoutesCollectionGetTablesResponse:
        """
        Parameters
        ----------
        collection_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcAppHttpRoutesCollectionGetTablesResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.tables.list(
            collection_id="collection_id",
        )
        """
        _response = self._raw_client.list(collection_id, request_options=request_options)
        return _response.data

    def create(
        self,
        collection_id: str,
        *,
        table_display_name: typing.Optional[str] = OMIT,
        table_img_url: typing.Optional[str] = OMIT,
        table_description: typing.Optional[str] = OMIT,
        schema: typing.Optional[typing.Sequence[TableConfigInputSchemaItem]] = OMIT,
        icon_emoji: typing.Optional[str] = OMIT,
        icon_asset_url: typing.Optional[str] = OMIT,
        icon_fill: typing.Optional[str] = OMIT,
        singular_name: typing.Optional[str] = OMIT,
        plural_name: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SrcAppHttpRoutesCollectionCreateTableResponse:
        """
        Parameters
        ----------
        collection_id : str

        table_display_name : typing.Optional[str]

        table_img_url : typing.Optional[str]

        table_description : typing.Optional[str]

        schema : typing.Optional[typing.Sequence[TableConfigInputSchemaItem]]

        icon_emoji : typing.Optional[str]

        icon_asset_url : typing.Optional[str]

        icon_fill : typing.Optional[str]

        singular_name : typing.Optional[str]

        plural_name : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcAppHttpRoutesCollectionCreateTableResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.tables.create(
            collection_id="collection_id",
        )
        """
        _response = self._raw_client.create(
            collection_id,
            table_display_name=table_display_name,
            table_img_url=table_img_url,
            table_description=table_description,
            schema=schema,
            icon_emoji=icon_emoji,
            icon_asset_url=icon_asset_url,
            icon_fill=icon_fill,
            singular_name=singular_name,
            plural_name=plural_name,
            request_options=request_options,
        )
        return _response.data

    def get(
        self, collection_id: str, table_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcAppHttpRoutesCollectionGetTableResponse:
        """
        Parameters
        ----------
        collection_id : str

        table_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcAppHttpRoutesCollectionGetTableResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.tables.get(
            collection_id="collection_id",
            table_id="table_id",
        )
        """
        _response = self._raw_client.get(collection_id, table_id, request_options=request_options)
        return _response.data

    def update(
        self,
        collection_id: str,
        table_id: str,
        *,
        table_display_name: typing.Optional[str] = OMIT,
        table_img_url: typing.Optional[str] = OMIT,
        table_description: typing.Optional[str] = OMIT,
        schema: typing.Optional[typing.Sequence[TableDataSchemaItem]] = OMIT,
        icon_emoji: typing.Optional[str] = OMIT,
        icon_asset_url: typing.Optional[str] = OMIT,
        icon_fill: typing.Optional[str] = OMIT,
        singular_name: typing.Optional[str] = OMIT,
        plural_name: typing.Optional[str] = OMIT,
        index_id: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SrcAppHttpRoutesCollectionUpdateTableResponse:
        """
        Parameters
        ----------
        collection_id : str

        table_id : str

        table_display_name : typing.Optional[str]

        table_img_url : typing.Optional[str]

        table_description : typing.Optional[str]

        schema : typing.Optional[typing.Sequence[TableDataSchemaItem]]

        icon_emoji : typing.Optional[str]

        icon_asset_url : typing.Optional[str]

        icon_fill : typing.Optional[str]

        singular_name : typing.Optional[str]

        plural_name : typing.Optional[str]

        index_id : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcAppHttpRoutesCollectionUpdateTableResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.tables.update(
            collection_id="collection_id",
            table_id="table_id",
        )
        """
        _response = self._raw_client.update(
            collection_id,
            table_id,
            table_display_name=table_display_name,
            table_img_url=table_img_url,
            table_description=table_description,
            schema=schema,
            icon_emoji=icon_emoji,
            icon_asset_url=icon_asset_url,
            icon_fill=icon_fill,
            singular_name=singular_name,
            plural_name=plural_name,
            index_id=index_id,
            request_options=request_options,
        )
        return _response.data

    def delete(
        self, collection_id: str, table_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcAppHttpRoutesCollectionDeleteTableResponse:
        """
        Delete a table given a collection_id and table_id.

        Parameters
        ----------
        collection_id : str

        table_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcAppHttpRoutesCollectionDeleteTableResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.tables.delete(
            collection_id="collection_id",
            table_id="table_id",
        )
        """
        _response = self._raw_client.delete(collection_id, table_id, request_options=request_options)
        return _response.data

    def get_schema(
        self, collection_id: str, table_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SchemaResponse:
        """
        Parameters
        ----------
        collection_id : str

        table_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SchemaResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.tables.get_schema(
            collection_id="collection_id",
            table_id="table_id",
        )
        """
        _response = self._raw_client.get_schema(collection_id, table_id, request_options=request_options)
        return _response.data

    def sync(
        self,
        collection_id: str,
        table_id: str,
        *,
        request: typing.Sequence[typing.Dict[str, typing.Optional[typing.Any]]],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SrcAppHttpRoutesCollectionSyncTableResponse:
        """
        Sync a table with a list of documents.

        Parameters
        ----------
        collection_id : str

        table_id : str

        request : typing.Sequence[typing.Dict[str, typing.Optional[typing.Any]]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcAppHttpRoutesCollectionSyncTableResponse
            Successful Response

        Examples
        --------
        from scoutos import Scout

        client = Scout(
            api_key="YOUR_API_KEY",
        )
        client.tables.sync(
            collection_id="collection_id",
            table_id="table_id",
            request=[{"key": "value"}],
        )
        """
        _response = self._raw_client.sync(collection_id, table_id, request=request, request_options=request_options)
        return _response.data


class AsyncTablesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawTablesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawTablesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawTablesClient
        """
        return self._raw_client

    async def list(
        self, collection_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcAppHttpRoutesCollectionGetTablesResponse:
        """
        Parameters
        ----------
        collection_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcAppHttpRoutesCollectionGetTablesResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.tables.list(
                collection_id="collection_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list(collection_id, request_options=request_options)
        return _response.data

    async def create(
        self,
        collection_id: str,
        *,
        table_display_name: typing.Optional[str] = OMIT,
        table_img_url: typing.Optional[str] = OMIT,
        table_description: typing.Optional[str] = OMIT,
        schema: typing.Optional[typing.Sequence[TableConfigInputSchemaItem]] = OMIT,
        icon_emoji: typing.Optional[str] = OMIT,
        icon_asset_url: typing.Optional[str] = OMIT,
        icon_fill: typing.Optional[str] = OMIT,
        singular_name: typing.Optional[str] = OMIT,
        plural_name: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SrcAppHttpRoutesCollectionCreateTableResponse:
        """
        Parameters
        ----------
        collection_id : str

        table_display_name : typing.Optional[str]

        table_img_url : typing.Optional[str]

        table_description : typing.Optional[str]

        schema : typing.Optional[typing.Sequence[TableConfigInputSchemaItem]]

        icon_emoji : typing.Optional[str]

        icon_asset_url : typing.Optional[str]

        icon_fill : typing.Optional[str]

        singular_name : typing.Optional[str]

        plural_name : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcAppHttpRoutesCollectionCreateTableResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.tables.create(
                collection_id="collection_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(
            collection_id,
            table_display_name=table_display_name,
            table_img_url=table_img_url,
            table_description=table_description,
            schema=schema,
            icon_emoji=icon_emoji,
            icon_asset_url=icon_asset_url,
            icon_fill=icon_fill,
            singular_name=singular_name,
            plural_name=plural_name,
            request_options=request_options,
        )
        return _response.data

    async def get(
        self, collection_id: str, table_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcAppHttpRoutesCollectionGetTableResponse:
        """
        Parameters
        ----------
        collection_id : str

        table_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcAppHttpRoutesCollectionGetTableResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.tables.get(
                collection_id="collection_id",
                table_id="table_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get(collection_id, table_id, request_options=request_options)
        return _response.data

    async def update(
        self,
        collection_id: str,
        table_id: str,
        *,
        table_display_name: typing.Optional[str] = OMIT,
        table_img_url: typing.Optional[str] = OMIT,
        table_description: typing.Optional[str] = OMIT,
        schema: typing.Optional[typing.Sequence[TableDataSchemaItem]] = OMIT,
        icon_emoji: typing.Optional[str] = OMIT,
        icon_asset_url: typing.Optional[str] = OMIT,
        icon_fill: typing.Optional[str] = OMIT,
        singular_name: typing.Optional[str] = OMIT,
        plural_name: typing.Optional[str] = OMIT,
        index_id: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SrcAppHttpRoutesCollectionUpdateTableResponse:
        """
        Parameters
        ----------
        collection_id : str

        table_id : str

        table_display_name : typing.Optional[str]

        table_img_url : typing.Optional[str]

        table_description : typing.Optional[str]

        schema : typing.Optional[typing.Sequence[TableDataSchemaItem]]

        icon_emoji : typing.Optional[str]

        icon_asset_url : typing.Optional[str]

        icon_fill : typing.Optional[str]

        singular_name : typing.Optional[str]

        plural_name : typing.Optional[str]

        index_id : typing.Optional[str]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcAppHttpRoutesCollectionUpdateTableResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.tables.update(
                collection_id="collection_id",
                table_id="table_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update(
            collection_id,
            table_id,
            table_display_name=table_display_name,
            table_img_url=table_img_url,
            table_description=table_description,
            schema=schema,
            icon_emoji=icon_emoji,
            icon_asset_url=icon_asset_url,
            icon_fill=icon_fill,
            singular_name=singular_name,
            plural_name=plural_name,
            index_id=index_id,
            request_options=request_options,
        )
        return _response.data

    async def delete(
        self, collection_id: str, table_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SrcAppHttpRoutesCollectionDeleteTableResponse:
        """
        Delete a table given a collection_id and table_id.

        Parameters
        ----------
        collection_id : str

        table_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcAppHttpRoutesCollectionDeleteTableResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.tables.delete(
                collection_id="collection_id",
                table_id="table_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(collection_id, table_id, request_options=request_options)
        return _response.data

    async def get_schema(
        self, collection_id: str, table_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SchemaResponse:
        """
        Parameters
        ----------
        collection_id : str

        table_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SchemaResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.tables.get_schema(
                collection_id="collection_id",
                table_id="table_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get_schema(collection_id, table_id, request_options=request_options)
        return _response.data

    async def sync(
        self,
        collection_id: str,
        table_id: str,
        *,
        request: typing.Sequence[typing.Dict[str, typing.Optional[typing.Any]]],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SrcAppHttpRoutesCollectionSyncTableResponse:
        """
        Sync a table with a list of documents.

        Parameters
        ----------
        collection_id : str

        table_id : str

        request : typing.Sequence[typing.Dict[str, typing.Optional[typing.Any]]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SrcAppHttpRoutesCollectionSyncTableResponse
            Successful Response

        Examples
        --------
        import asyncio

        from scoutos import AsyncScout

        client = AsyncScout(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.tables.sync(
                collection_id="collection_id",
                table_id="table_id",
                request=[{"key": "value"}],
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.sync(
            collection_id, table_id, request=request, request_options=request_options
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .workflow_logs_list_logs_response import WorkflowLogsListLogsResponse

__all__ = ["WorkflowLogsListLogsResponse"]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .integration_connection_auth_type import IntegrationConnectionAuthType
from .integration_connection_integration_type import IntegrationConnectionIntegrationType


class IntegrationConnection(UncheckedBaseModel):
    id: str
    auth_client: str
    integration_type: IntegrationConnectionIntegrationType
    auth_type: IntegrationConnectionAuthType
    api_key_secret_ref: typing.Optional[str] = None
    access_token_secret_ref: typing.Optional[str] = None
    refresh_token_secret_ref: typing.Optional[str] = None
    connected: bool
    metadata: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None
    scopes: typing.Optional[typing.List[str]] = None
    created_at: dt.datetime
    updated_at: dt.datetime
    expires_in: typing.Optional[int] = None
    has_permission: typing.Optional[bool] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .table_view_settings_row_height import TableViewSettingsRowHeight


class TableViewSettings(UncheckedBaseModel):
    column_visibility: typing.Optional[typing.Dict[str, bool]] = None
    column_order: typing.Optional[typing.List[str]] = None
    column_widths: typing.Optional[typing.Dict[str, int]] = None
    type: typing.Literal["table"] = "table"
    row_height: typing.Optional[TableViewSettingsRowHeight] = None
    show_row_numbers: typing.Optional[bool] = None
    wrap_text: typing.Optional[bool] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.request_options import RequestOptions
from ..core.serialization import convert_and_respect_annotation_metadata
from ..core.unchecked_base_model import construct_type
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.collection_view_state_input import CollectionViewStateInput
from ..types.delete_view_response import DeleteViewResponse
from ..types.http_validation_error import HttpValidationError
from ..types.src_app_http_routes_collection_create_collection_response import (
    SrcAppHttpRoutesCollectionCreateCollectionResponse,
)
from ..types.src_app_http_routes_collection_delete_collection_response import (
    SrcAppHttpRoutesCollectionDeleteCollectionResponse,
)
from ..types.src_app_http_routes_collection_get_collection_response import (
    SrcAppHttpRoutesCollectionGetCollectionResponse,
)
from ..types.src_app_http_routes_collection_get_collections_response import (
    SrcAppHttpRoutesCollectionGetCollectionsResponse,
)
from ..types.src_app_http_routes_collection_update_collection_response import (
    SrcAppHttpRoutesCollectionUpdateCollectionResponse,
)
from ..types.view_filter import ViewFilter
from ..types.view_list_response import ViewListResponse
from ..types.view_query_input import ViewQueryInput
from ..types.view_response import ViewResponse
from ..types.view_state_response import ViewStateResponse
from ..types.view_visibility import ViewVisibility
from .types.create_view_request_settings import CreateViewRequestSettings
from .types.create_view_request_type import CreateViewRequestType
from .types.update_view_request_settings import UpdateViewRequestSettings
from .types.update_view_request_type import UpdateViewRequestType

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawCollectionsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list(
        self,
        *,
        start_at: typing.Optional[str] = None,
        limit: typing.Optional[int] = None,
        query: typing.Optional[str] = None,
        tags: typing.Optional[str] = None,
        sort: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[SrcAppHttpRoutesCollectionGetCollectionsResponse]:
        """
        Parameters
        ----------
        start_at : typing.Optional[str]
            created_at to start at

        limit : typing.Optional[int]
            Limit of records to return

        query : typing.Optional[str]
            Search query

        tags : typing.Optional[str]
            Filter by tags

        sort : typing.Optional[str]
            Sort

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[SrcAppHttpRoutesCollectionGetCollectionsResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v2/collections",
            method="GET",
            params={
                "start_at": start_at,
                "limit": limit,
                "query": query,
                "tags": tags,
                "sort": sort,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SrcAppHttpRoutesCollectionGetCollectionsResponse,
                    construct_type(
                        type_=SrcAppHttpRoutesCollectionGetCollectionsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def create(
        self,
        *,
        collection_display_name: typing.Optional[str] = OMIT,
        collection_img_url: typing.Optional[str] = OMIT,
        collection_description: typing.Optional[str] = OMIT,
        tags: typing.Optional[typing.Sequence[str]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[SrcAppHttpRoutesCollectionCreateCollectionResponse]:
        """
        Parameters
        ----------
        collection_display_name : typing.Optional[str]

        collection_img_url : typing.Optional[str]

        collection_description : typing.Optional[str]

        tags : typing.Optional[typing.Sequence[str]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[SrcAppHttpRoutesCollectionCreateCollectionResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "v2/collections",
            method="POST",
            json={
                "collection_display_name": collection_display_name,
                "collection_img_url": collection_img_url,
                "collection_description": collection_description,
                "tags": tags,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SrcAppHttpRoutesCollectionCreateCollectionResponse,
                    construct_type(
                        type_=SrcAppHttpRoutesCollectionCreateCollectionResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get(
        self, collection_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[SrcAppHttpRoutesCollectionGetCollectionResponse]:
        """
        Parameters
        ----------
        collection_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[SrcAppHttpRoutesCollectionGetCollectionResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SrcAppHttpRoutesCollectionGetCollectionResponse,
                    construct_type(
                        type_=SrcAppHttpRoutesCollectionGetCollectionResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def update(
        self,
        collection_id: str,
        *,
        collection_display_name: typing.Optional[str] = OMIT,
        collection_img_url: typing.Optional[str] = OMIT,
        collection_description: typing.Optional[str] = OMIT,
        tags: typing.Optional[typing.Sequence[str]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[SrcAppHttpRoutesCollectionUpdateCollectionResponse]:
        """
        Parameters
        ----------
        collection_id : str

        collection_display_name : typing.Optional[str]

        collection_img_url : typing.Optional[str]

        collection_description : typing.Optional[str]

        tags : typing.Optional[typing.Sequence[str]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[SrcAppHttpRoutesCollectionUpdateCollectionResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}",
            method="PUT",
            json={
                "collection_display_name": collection_display_name,
                "collection_img_url": collection_img_url,
                "collection_description": collection_description,
                "tags": tags,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SrcAppHttpRoutesCollectionUpdateCollectionResponse,
                    construct_type(
                        type_=SrcAppHttpRoutesCollectionUpdateCollectionResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def delete(
        self, collection_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[SrcAppHttpRoutesCollectionDeleteCollectionResponse]:
        """
        Delete a collection given a collection_id.

        Parameters
        ----------
        collection_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[SrcAppHttpRoutesCollectionDeleteCollectionResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SrcAppHttpRoutesCollectionDeleteCollectionResponse,
                    construct_type(
                        type_=SrcAppHttpRoutesCollectionDeleteCollectionResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_views(
        self, collection_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[ViewStateResponse]:
        """
        Parameters
        ----------
        collection_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ViewStateResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/views",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ViewStateResponse,
                    construct_type(
                        type_=ViewStateResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def update_views(
        self,
        collection_id: str,
        *,
        view_state: CollectionViewStateInput,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ViewStateResponse]:
        """
        Parameters
        ----------
        collection_id : str

        view_state : CollectionViewStateInput

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ViewStateResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/views",
            method="PUT",
            json={
                "view_state": convert_and_respect_annotation_metadata(
                    object_=view_state, annotation=CollectionViewStateInput, direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ViewStateResponse,
                    construct_type(
                        type_=ViewStateResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def delete_views(
        self, collection_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[ViewStateResponse]:
        """
        Parameters
        ----------
        collection_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ViewStateResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/views",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ViewStateResponse,
                    construct_type(
                        type_=ViewStateResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def list_individual_views(
        self, collection_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[ViewListResponse]:
        """
        Parameters
        ----------
        collection_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ViewListResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/views/list",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ViewListResponse,
                    construct_type(
                        type_=ViewListResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def create_view(
        self,
        collection_id: str,
        *,
        name: str,
        type: typing.Optional[CreateViewRequestType] = OMIT,
        emoji: typing.Optional[str] = OMIT,
        table_id: typing.Optional[str] = OMIT,
        settings: typing.Optional[CreateViewRequestSettings] = OMIT,
        visibility: typing.Optional[ViewVisibility] = OMIT,
        shared_with: typing.Optional[typing.Sequence[str]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ViewResponse]:
        """
        Parameters
        ----------
        collection_id : str

        name : str

        type : typing.Optional[CreateViewRequestType]

        emoji : typing.Optional[str]

        table_id : typing.Optional[str]

        settings : typing.Optional[CreateViewRequestSettings]

        visibility : typing.Optional[ViewVisibility]

        shared_with : typing.Optional[typing.Sequence[str]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ViewResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/views/create",
            method="POST",
            json={
                "name": name,
                "type": type,
                "emoji": emoji,
                "table_id": table_id,
                "settings": convert_and_respect_annotation_metadata(
                    object_=settings, annotation=CreateViewRequestSettings, direction="write"
                ),
                "visibility": visibility,
                "shared_with": shared_with,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ViewResponse,
                    construct_type(
                        type_=ViewResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def update_view(
        self,
        collection_id: str,
        view_id: str,
        *,
        name: typing.Optional[str] = OMIT,
        type: typing.Optional[UpdateViewRequestType] = OMIT,
        emoji: typing.Optional[str] = OMIT,
        settings: typing.Optional[UpdateViewRequestSettings] = OMIT,
        visibility: typing.Optional[ViewVisibility] = OMIT,
        shared_with: typing.Optional[typing.Sequence[str]] = OMIT,
        filters: typing.Optional[typing.Sequence[ViewFilter]] = OMIT,
        query: typing.Optional[ViewQueryInput] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ViewResponse]:
        """
        Parameters
        ----------
        collection_id : str

        view_id : str

        name : typing.Optional[str]

        type : typing.Optional[UpdateViewRequestType]

        emoji : typing.Optional[str]

        settings : typing.Optional[UpdateViewRequestSettings]

        visibility : typing.Optional[ViewVisibility]

        shared_with : typing.Optional[typing.Sequence[str]]

        filters : typing.Optional[typing.Sequence[ViewFilter]]

        query : typing.Optional[ViewQueryInput]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ViewResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/views/{jsonable_encoder(view_id)}",
            method="PUT",
            json={
                "name": name,
                "type": type,
                "emoji": emoji,
                "settings": convert_and_respect_annotation_metadata(
                    object_=settings, annotation=UpdateViewRequestSettings, direction="write"
                ),
                "visibility": visibility,
                "shared_with": shared_with,
                "filters": convert_and_respect_annotation_metadata(
                    object_=filters, annotation=typing.Sequence[ViewFilter], direction="write"
                ),
                "query": convert_and_respect_annotation_metadata(
                    object_=query, annotation=ViewQueryInput, direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ViewResponse,
                    construct_type(
                        type_=ViewResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def delete_view(
        self, collection_id: str, view_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[DeleteViewResponse]:
        """
        Parameters
        ----------
        collection_id : str

        view_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[DeleteViewResponse]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/views/{jsonable_encoder(view_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    DeleteViewResponse,
                    construct_type(
                        type_=DeleteViewResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawCollectionsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list(
        self,
        *,
        start_at: typing.Optional[str] = None,
        limit: typing.Optional[int] = None,
        query: typing.Optional[str] = None,
        tags: typing.Optional[str] = None,
        sort: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[SrcAppHttpRoutesCollectionGetCollectionsResponse]:
        """
        Parameters
        ----------
        start_at : typing.Optional[str]
            created_at to start at

        limit : typing.Optional[int]
            Limit of records to return

        query : typing.Optional[str]
            Search query

        tags : typing.Optional[str]
            Filter by tags

        sort : typing.Optional[str]
            Sort

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[SrcAppHttpRoutesCollectionGetCollectionsResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v2/collections",
            method="GET",
            params={
                "start_at": start_at,
                "limit": limit,
                "query": query,
                "tags": tags,
                "sort": sort,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SrcAppHttpRoutesCollectionGetCollectionsResponse,
                    construct_type(
                        type_=SrcAppHttpRoutesCollectionGetCollectionsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def create(
        self,
        *,
        collection_display_name: typing.Optional[str] = OMIT,
        collection_img_url: typing.Optional[str] = OMIT,
        collection_description: typing.Optional[str] = OMIT,
        tags: typing.Optional[typing.Sequence[str]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[SrcAppHttpRoutesCollectionCreateCollectionResponse]:
        """
        Parameters
        ----------
        collection_display_name : typing.Optional[str]

        collection_img_url : typing.Optional[str]

        collection_description : typing.Optional[str]

        tags : typing.Optional[typing.Sequence[str]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[SrcAppHttpRoutesCollectionCreateCollectionResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v2/collections",
            method="POST",
            json={
                "collection_display_name": collection_display_name,
                "collection_img_url": collection_img_url,
                "collection_description": collection_description,
                "tags": tags,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SrcAppHttpRoutesCollectionCreateCollectionResponse,
                    construct_type(
                        type_=SrcAppHttpRoutesCollectionCreateCollectionResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get(
        self, collection_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[SrcAppHttpRoutesCollectionGetCollectionResponse]:
        """
        Parameters
        ----------
        collection_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[SrcAppHttpRoutesCollectionGetCollectionResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SrcAppHttpRoutesCollectionGetCollectionResponse,
                    construct_type(
                        type_=SrcAppHttpRoutesCollectionGetCollectionResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def update(
        self,
        collection_id: str,
        *,
        collection_display_name: typing.Optional[str] = OMIT,
        collection_img_url: typing.Optional[str] = OMIT,
        collection_description: typing.Optional[str] = OMIT,
        tags: typing.Optional[typing.Sequence[str]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[SrcAppHttpRoutesCollectionUpdateCollectionResponse]:
        """
        Parameters
        ----------
        collection_id : str

        collection_display_name : typing.Optional[str]

        collection_img_url : typing.Optional[str]

        collection_description : typing.Optional[str]

        tags : typing.Optional[typing.Sequence[str]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[SrcAppHttpRoutesCollectionUpdateCollectionResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}",
            method="PUT",
            json={
                "collection_display_name": collection_display_name,
                "collection_img_url": collection_img_url,
                "collection_description": collection_description,
                "tags": tags,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SrcAppHttpRoutesCollectionUpdateCollectionResponse,
                    construct_type(
                        type_=SrcAppHttpRoutesCollectionUpdateCollectionResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def delete(
        self, collection_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[SrcAppHttpRoutesCollectionDeleteCollectionResponse]:
        """
        Delete a collection given a collection_id.

        Parameters
        ----------
        collection_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[SrcAppHttpRoutesCollectionDeleteCollectionResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    SrcAppHttpRoutesCollectionDeleteCollectionResponse,
                    construct_type(
                        type_=SrcAppHttpRoutesCollectionDeleteCollectionResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_views(
        self, collection_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[ViewStateResponse]:
        """
        Parameters
        ----------
        collection_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ViewStateResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/views",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ViewStateResponse,
                    construct_type(
                        type_=ViewStateResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def update_views(
        self,
        collection_id: str,
        *,
        view_state: CollectionViewStateInput,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ViewStateResponse]:
        """
        Parameters
        ----------
        collection_id : str

        view_state : CollectionViewStateInput

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ViewStateResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/views",
            method="PUT",
            json={
                "view_state": convert_and_respect_annotation_metadata(
                    object_=view_state, annotation=CollectionViewStateInput, direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ViewStateResponse,
                    construct_type(
                        type_=ViewStateResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def delete_views(
        self, collection_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[ViewStateResponse]:
        """
        Parameters
        ----------
        collection_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ViewStateResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/views",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ViewStateResponse,
                    construct_type(
                        type_=ViewStateResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def list_individual_views(
        self, collection_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[ViewListResponse]:
        """
        Parameters
        ----------
        collection_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ViewListResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/views/list",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ViewListResponse,
                    construct_type(
                        type_=ViewListResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def create_view(
        self,
        collection_id: str,
        *,
        name: str,
        type: typing.Optional[CreateViewRequestType] = OMIT,
        emoji: typing.Optional[str] = OMIT,
        table_id: typing.Optional[str] = OMIT,
        settings: typing.Optional[CreateViewRequestSettings] = OMIT,
        visibility: typing.Optional[ViewVisibility] = OMIT,
        shared_with: typing.Optional[typing.Sequence[str]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ViewResponse]:
        """
        Parameters
        ----------
        collection_id : str

        name : str

        type : typing.Optional[CreateViewRequestType]

        emoji : typing.Optional[str]

        table_id : typing.Optional[str]

        settings : typing.Optional[CreateViewRequestSettings]

        visibility : typing.Optional[ViewVisibility]

        shared_with : typing.Optional[typing.Sequence[str]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ViewResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/views/create",
            method="POST",
            json={
                "name": name,
                "type": type,
                "emoji": emoji,
                "table_id": table_id,
                "settings": convert_and_respect_annotation_metadata(
                    object_=settings, annotation=CreateViewRequestSettings, direction="write"
                ),
                "visibility": visibility,
                "shared_with": shared_with,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ViewResponse,
                    construct_type(
                        type_=ViewResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def update_view(
        self,
        collection_id: str,
        view_id: str,
        *,
        name: typing.Optional[str] = OMIT,
        type: typing.Optional[UpdateViewRequestType] = OMIT,
        emoji: typing.Optional[str] = OMIT,
        settings: typing.Optional[UpdateViewRequestSettings] = OMIT,
        visibility: typing.Optional[ViewVisibility] = OMIT,
        shared_with: typing.Optional[typing.Sequence[str]] = OMIT,
        filters: typing.Optional[typing.Sequence[ViewFilter]] = OMIT,
        query: typing.Optional[ViewQueryInput] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ViewResponse]:
        """
        Parameters
        ----------
        collection_id : str

        view_id : str

        name : typing.Optional[str]

        type : typing.Optional[UpdateViewRequestType]

        emoji : typing.Optional[str]

        settings : typing.Optional[UpdateViewRequestSettings]

        visibility : typing.Optional[ViewVisibility]

        shared_with : typing.Optional[typing.Sequence[str]]

        filters : typing.Optional[typing.Sequence[ViewFilter]]

        query : typing.Optional[ViewQueryInput]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ViewResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/views/{jsonable_encoder(view_id)}",
            method="PUT",
            json={
                "name": name,
                "type": type,
                "emoji": emoji,
                "settings": convert_and_respect_annotation_metadata(
                    object_=settings, annotation=UpdateViewRequestSettings, direction="write"
                ),
                "visibility": visibility,
                "shared_with": shared_with,
                "filters": convert_and_respect_annotation_metadata(
                    object_=filters, annotation=typing.Sequence[ViewFilter], direction="write"
                ),
                "query": convert_and_respect_annotation_metadata(
                    object_=query, annotation=ViewQueryInput, direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ViewResponse,
                    construct_type(
                        type_=ViewResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def delete_view(
        self, collection_id: str, view_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[DeleteViewResponse]:
        """
        Parameters
        ----------
        collection_id : str

        view_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[DeleteViewResponse]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v2/collections/{jsonable_encoder(collection_id)}/views/{jsonable_encoder(view_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    DeleteViewResponse,
                    construct_type(
                        type_=DeleteViewResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        HttpValidationError,
                        construct_type(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)
